# runeq-python

Python 3 Standard Development Kit (SDK) for Rune Lab's Query API: `runeq`

## References

* Library documentation: [https://runeq.readthedocs.io/en/latest](https://runeq.readthedocs.io/en/latest)
* API documentation: [https://docs.runelabs.io](https://docs.runelabs.io)
* Rune Labs home page: [https://runelabs.io](https://runelabs.io)

## Installation

Python 3.6+ is required.

To install the library using pip:

    pip3 install runeq

To install from source:

    python3 setup.py install
